package Ratpoison;
$RATPOISON=$ENV{RATPOISON} ? $ENV{RATPOISON} : "ratpoison";
sub command { my $a = "@_"; $a =~ s/(')/'\\''/g; return `$RATPOISON -c '$a'`; }
sub abort { return command ("abort", @_); }
sub addhook { return command ("addhook", @_); }
sub alias { return command ("alias", @_); }
sub banish { return command ("banish", @_); }
sub chdir { return command ("chdir", @_); }
sub clrunmanaged { return command ("clrunmanaged", @_); }
sub colon { return command ("colon", @_); }
sub curframe { return command ("curframe", @_); }
sub definekey { return command ("definekey", @_); }
sub undefinekey { return command ("undefinekey", @_); }
sub delete { return command ("delete", @_); }
sub delkmap { return command ("delkmap", @_); }
sub echo { return command ("echo", @_); }
sub escape { return command ("escape", @_); }
sub exec { return command ("exec", @_); }
sub execa { return command ("execa", @_); }
sub execf { return command ("execf", @_); }
sub fdump { return command ("fdump", @_); }
sub focus { return command ("focus", @_); }
sub focusprev { return command ("focusprev", @_); }
sub focusdown { return command ("focusdown", @_); }
sub exchangeup { return command ("exchangeup", @_); }
sub exchangedown { return command ("exchangedown", @_); }
sub exchangeleft { return command ("exchangeleft", @_); }
sub exchangeright { return command ("exchangeright", @_); }
sub swap { return command ("swap", @_); }
sub focuslast { return command ("focuslast", @_); }
sub focusleft { return command ("focusleft", @_); }
sub focusright { return command ("focusright", @_); }
sub focusup { return command ("focusup", @_); }
sub frestore { return command ("frestore", @_); }
sub fselect { return command ("fselect", @_); }
sub gdelete { return command ("gdelete", @_); }
sub getenv { return command ("getenv", @_); }
sub gmerge { return command ("gmerge", @_); }
sub gmove { return command ("gmove", @_); }
sub gnew { return command ("gnew", @_); }
sub gnewbg { return command ("gnewbg", @_); }
sub gnumber { return command ("gnumber", @_); }
sub grename { return command ("grename", @_); }
sub gnext { return command ("gnext", @_); }
sub gprev { return command ("gprev", @_); }
sub gother { return command ("gother", @_); }
sub gravity { return command ("gravity", @_); }
sub groups { return command ("groups", @_); }
sub gselect { return command ("gselect", @_); }
sub help { return command ("help", @_); }
sub hsplit { return command ("hsplit", @_); }
sub info { return command ("info", @_); }
sub kill { return command ("kill", @_); }
sub lastmsg { return command ("lastmsg", @_); }
sub license { return command ("license", @_); }
sub link { return command ("link", @_); }
sub listhook { return command ("listhook", @_); }
sub meta { return command ("meta", @_); }
sub msgwait { return command ("msgwait", @_); }
sub newkmap { return command ("newkmap", @_); }
sub newwm { return command ("newwm", @_); }
sub next { return command ("next", @_); }
sub nextscreen { return command ("nextscreen", @_); }
sub number { return command ("number", @_); }
sub only { return command ("only", @_); }
sub other { return command ("other", @_); }
sub prev { return command ("prev", @_); }
sub prevscreen { return command ("prevscreen", @_); }
sub quit { return command ("quit", @_); }
sub ratinfo { return command ("ratinfo", @_); }
sub ratrelinfo { return command ("ratrelinfo", @_); }
sub banishrel { return command ("banishrel", @_); }
sub ratwarp { return command ("ratwarp", @_); }
sub ratrelwarp { return command ("ratrelwarp", @_); }
sub ratclick { return command ("ratclick", @_); }
sub rathold { return command ("rathold", @_); }
sub readkey { return command ("readkey", @_); }
sub redisplay { return command ("redisplay", @_); }
sub remhook { return command ("remhook", @_); }
sub remove { return command ("remove", @_); }
sub resize { return command ("resize", @_); }
sub restart { return command ("restart", @_); }
sub rudeness { return command ("rudeness", @_); }
sub select { return command ("select", @_); }
sub set { return command ("set", @_); }
sub setenv { return command ("setenv", @_); }
sub shrink { return command ("shrink", @_); }
sub sfrestore { return command ("sfrestore", @_); }
sub source { return command ("source", @_); }
sub sselect { return command ("sselect", @_); }
sub startup_message { return command ("startup_message", @_); }
sub time { return command ("time", @_); }
sub title { return command ("title", @_); }
sub tmpwm { return command ("tmpwm", @_); }
sub unalias { return command ("unalias", @_); }
sub unmanage { return command ("unmanage", @_); }
sub unsetenv { return command ("unsetenv", @_); }
sub verbexec { return command ("verbexec", @_); }
sub version { return command ("version", @_); }
sub vsplit { return command ("vsplit", @_); }
sub warp { return command ("warp", @_); }
sub windows { return command ("windows", @_); }
sub cnext { return command ("cnext", @_); }
sub cother { return command ("cother", @_); }
sub cprev { return command ("cprev", @_); }
sub dedicate { return command ("dedicate", @_); }
sub describekey { return command ("describekey", @_); }
sub inext { return command ("inext", @_); }
sub iother { return command ("iother", @_); }
sub iprev { return command ("iprev", @_); }
sub prompt { return command ("prompt", @_); }
sub sdump { return command ("sdump", @_); }
sub sfdump { return command ("sfdump", @_); }
sub undo { return command ("undo", @_); }
sub redo { return command ("redo", @_); }
sub putsel { return command ("putsel", @_); }
sub getsel { return command ("getsel", @_); }
sub commands { return command ("commands", @_); }
